@@ -24,11 +24,14 @@
 #' @param probs Enter the probability for the quantile interval. The default value is \code{0.95}.
 #' @param geo.unit  Enter the name of the stratification variable used in post stratification.
 #' @param geo.id Enter one value of interest among the values of the stratification variable.
+#' @param xlab Enter the label to be displayed on the x-axis. If not provided, a default label will be used.
+#' @param ylab Enter the label for the y-axis if needed.
 #' @param ... Additional arguments to be passed
 #' @return The plot is returned based on the specified option.: 
-#' \item{out}{If average is \code{"obs"} or \code{"post"}, a bar plot or summary plot is generated based on
-#'the selected averaging criterion. If average is \code{"both"}, a boxplot is displayed to
-#'show the distribution of Shapley values computed using both criteria.
+#' \item{out}{If average is \code{"obs"} or \code{"post"}, a bar plot or summary plot is generated based on the selected averaging criterion.
+#' When \code{average} is set to \code{"both"}, either a bar plot or a boxplot comparing the distributions of Shapley values computed under the two averaging criteria is generated.
+#' In the case where a boxplot is produced, the observation-based and posterior-sample-based summaries can additionally be rendered separately
+#' via \code{out$observation} and \code{out$post}, respectively.
 #' If adjust is \code{TRUE}, the adjusted Shapley values are displayed.
 #' If \code{num_post} is specified, a bar plot or summary plot for the selected posterior sample is generated.}
 #' @importFrom dplyr n
@@ -36,7 +39,8 @@
 #' @export
 
 plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
-                             plot.flag=TRUE, adjust= FALSE,  probs=0.95, title=NULL,geo.unit=NULL,geo.id=NULL,...){
+                             plot.flag=TRUE, adjust= FALSE,  probs=0.95, 
+                             title=NULL,geo.unit=NULL,geo.id=NULL,xlab=NULL, ylab= NULL,...){
   
   if (!inherits(x, "Explainbarp") ) {
     stop("The input object must be of class 'Explainbarp'.")
@@ -46,6 +50,17 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
     return(invisible(NULL))
   }
   
+  
+  if (is.null(xlab)) { 
+    y_text <- if (!is.null(type) && type == "bees") {
+      "SHAP (Impact on model output)"
+    } else {
+      "Importance"
+    }} else { 
+    y_text = xlab 
+  }
+  if (is.null(ylab)){x_text =""} else {x_text = ylab}
+  
   object <- x;
   value <- variable <- n <- Average_re <- 0;
   geo_check <- str_split(colnames(object$newdata), paste0( geo.unit,"_"),simplify = T)[,2]
@@ -117,7 +132,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       
       sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
       
-      out <- bar_plot (Local_mean,probs = NULL, plot.flag = FALSE ,title  )
+      out <- bar_plot (Local_mean,probs = NULL, plot.flag = FALSE ,title,x_text, y_text)
       ymin <-  (- diff(range(out$coordinates$limits$y)) * 0.02)
       
       out <- out +
@@ -128,7 +143,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       
     } else if (isTRUE( type == "bees")){
       #  summary plot
-      out <- summary_plot (local_obs,title )
+      out <- summary_plot (local_obs,title ,x_text, y_text)
       print(out)
     }
     
@@ -164,7 +179,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
       obs_mean_shap <- obs_mean_shap[, colSums(is.nan(obs_mean_shap)) != nrow(obs_mean_shap)]
       
       
-      out <- bar_plot (obs_mean_shap, probs, plot.flag= T,title )
+      out <- bar_plot (obs_mean_shap, probs, plot.flag= T,title, x_text, y_text )
       print ( out )
       
       if ( isTRUE(type =="bees") ) {
@@ -213,7 +228,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
           sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
           
           
-          out <- bar_plot (Local_mean, probs = NULL, plot.flag = FALSE,title  )
+          out <- bar_plot (Local_mean, probs = NULL, plot.flag = FALSE,title, x_text, y_text)
           ymin <- (- diff(range(out$coordinates$limits$y)) * 0.02)
           
           out <- out +
@@ -224,7 +239,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         } else if (isTRUE( type == "bees")){
           
           #  summary plot
-          out <- summary_plot (local_total,title )
+          out <- summary_plot (local_total,title, x_text, y_text)
           print ( out )
         }
         
@@ -253,12 +268,12 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         
         if (isTRUE(type == "bees") | is.null (type)){
           # Local SHAP summary plot - i th posterior
-          out <- summary_plot (local_obs ,title)
+          out <- summary_plot (local_obs ,title, x_text, y_text)
           annotate_figure(out, top =  text_grob(paste0("Sample number = ", num_post),
                                                 hjust = 1, x = 0.95,vjust = 1.05, size = 10 ))
         } else if (isTRUE(type == "bar")) {
           
-          out <- bar_plot (abs(obs),probs =NULL, plot.flag = FALSE,title  )
+          out <- bar_plot (abs(obs),probs =NULL, plot.flag = FALSE,title, x_text, y_text)
           
           sample_summary <-  local_obs$long %>% filter (is.na (value)==F) %>%
             select(c("variable", "value")) %>% group_by(variable) %>% mutate (n=n()) %>%
@@ -366,7 +381,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         left_p <-  data_list$total_long %>% filter (is.na (value)==F & Average_re=="Observation") %>%
           ggplot(  aes(x= variable, y=value, fill= Average_re)) +
           geom_boxplot() + coord_flip() + theme_bw(base_size = 11) +
-          labs(fill = "", x="",y="Mean(|SHAP|)") +
+          labs(fill = "", x=x_text,y=y_text) +
           scale_x_discrete(limits = rev(obs_variable),
                            labels = rev(obs_variable))+
           scale_fill_manual(values=c( "#F8766D"))+
@@ -389,7 +404,7 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
         right_p <-  data_list$total_long %>% filter (is.na (value)==F & Average_re=="Samples")%>%
           ggplot(  aes(x= variable, y=value, fill= Average_re )) +
           geom_boxplot() + coord_flip() + theme_bw(base_size = 11) +
-          labs(fill = "", x="",y="Mean(|SHAP|)") +
+          labs(fill = "", x=x_text,y=y_text) +
           scale_x_discrete(limits = rev(obs_variable),
                            labels = rev(obs_variable))+
           scale_fill_manual(values=c( "#00BFC4"))+
@@ -400,17 +415,25 @@ plot.Explainbarp <- function(x, average = NULL, type = NULL,  num_post= NULL,
                                       hjust = 1, label = sample_summary$percent , size = 3 )
 
 
-       grid.arrange(left_p, right_p, ncol= 1, top=textGrob(title, x = 0.2, hjust = 0 ) )
+        out <- list(
+          combined = gridExtra::arrangeGrob(left_p, right_p, ncol = 1,
+                                 top = textGrob(title, x = 0.2, hjust = 0)),
+          observation = left_p,
+          post = right_p
+        )
+        grid::grid.draw(out$combined)
+        return(invisible(out))
 
       if ( isTRUE(type =="bees") ) {
         message("In Average = 'both',\n a baxplot is also provided by entering type='bees'.")
       }
 
     } else if (isTRUE(type == "bar")  ){
+      
        out <- ggplot( data_list$mean_data, aes(x= variable, y= mean, fill =  Average_re )) +
         geom_bar( stat = "identity" , position="dodge") +coord_flip() + theme_bw(base_size = 11) +
         scale_fill_manual(values=c("#00BFC4","#F8766D"))+
-        labs(fill = "Criteria for average ", x="",y="Mean(|SHAP|)") +
+        labs(fill = "Criteria for average ", x=x_text,y=y_text) +
         scale_x_discrete(limits = rev(obs_variable), labels = rev(obs_variable)) +
         ylim(c(0,max( data_list$mean_data$mean) ))+
         geom_text(aes( label = sprintf("%.3f",round(mean,3)) ),
